@@ -25,13 +25,20 @@
  */
 
 #include <string.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <errno.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <syslog.h>
+
 #include "COSUtils.h"
 
 #warning VERIFY the version string before each distinct build submission
 static const char	*sysStrList [] =
 {
-	/* 01 */	"1.5.2",
-	/* 02 */	"197.5"
+	/* 01 */	"1.5.3",
+	/* 02 */	"197.8"
 };
 
 /*
@@ -96,3 +103,42 @@ const char* COSUtils::GetStringFromList ( const uInt32 inListID, const sInt32 in
 	return( pStr );
 
 } // GetXndString
+
+int dsTouch( const char* path )
+{
+	int		fd = -1;
+	int		status = 0;
+	
+	if ( path )
+	{
+		fd = open( path, O_NOFOLLOW | O_CREAT | O_EXCL, S_IRUSR | S_IWUSR );
+		
+		if ( fd >= 0 )
+		{
+			if ( close( fd ) )
+				status = errno;
+		}
+		else
+		{
+			status = errno;
+			syslog( LOG_ALERT, "WARNING - dsTouch: file was asked to be opened <%s>: (%s)\n", path, strerror(errno) );
+		}
+	}
+	else
+		status = EINVAL;
+		
+	return status;
+}
+
+int dsRemove( const char* path  )
+{
+	if ( unlink( path ) )
+	{
+		syslog( LOG_ALERT, "WARNING - dsRemove: file was asked to be deleted that should be zero length but isn't! <%s> (%s)\n", path, strerror(errno) );
+
+		return errno;
+	}
+	else
+		return 0;
+}
+
